@@ -8,7 +8,7 @@ def failure_handler(sender, task_id, exception, args, kwargs, traceback, einfo,
         "kwargs": kwargs
     }
 
-    bugsnag.notify(exception, traceback=traceback,
+    bugsnag.auto_notify(exception, traceback=traceback,
                               context=sender.name,
                               extra_data=task)
 
