@@ -1,14 +1,17 @@
-import urlparse
-
 from flask import got_request_exception, request, session
+
 import bugsnag
+from bugsnag.wsgi import request_path
+
 
 def handle_exceptions(app):
     got_request_exception.connect(__log_exception, app)
 
+
+# pylint: disable-msg=W0613
 def __log_exception(sender, exception, **extra):
     bugsnag.configure_request(
-        context="%s %s" % (request.method, request.path),
+        context="%s %s" % (request.method, request_path(request.environ)),
         user_id=request.remote_addr,
         request_data={
             "url": request.base_url,
@@ -22,4 +25,4 @@ def __log_exception(sender, exception, **extra):
 
     bugsnag.auto_notify(exception)
 
-    bugsnag.clear_request_config()
\ No newline at end of file
+    bugsnag.clear_request_config()
