@@ -34,6 +34,8 @@ class Notification(object):
     """
     NOTIFIER_NAME = "Python Bugsnag Notifier"
     NOTIFIER_URL = "https://github.com/bugsnag/bugsnag-python"
+    PAYLOAD_VERSION = "2"
+    SUPPORTED_SEVERITIES = ["info", "warning", "error"]
 
     def __init__(self, exception, config, request_config, **options):
         self.exception = exception
@@ -41,6 +43,11 @@ class Notification(object):
         self.config = config
         self.request_config = request_config
 
+        if "severity" in options and options["severity"] in self.SUPPORTED_SEVERITIES:
+            self.severity = options["severity"]
+        else:
+            self.severity = "warning"
+
     def deliver(self):
         """
         Deliver the exception notification to Bugsnag.
@@ -129,6 +136,8 @@ class Notification(object):
                     "version": notifier_version,
                 },
                 "events": [{
+                    "payloadVersion": self.PAYLOAD_VERSION,
+                    "severity": self.severity,
                     "releaseStage": self.config.get("release_stage", self.options),
                     "appVersion": self.config.get("app_version", self.options),
                     "context": self.request_config.get("context", self.options),
