@@ -3,14 +3,16 @@ import traceback
 
 import bugsnag
 
+
 MAX_STRING_LENGTH = 1024
 
+
 def sanitize_object(obj, **kwargs):
     filters = kwargs.get("filters", [])
 
     if isinstance(obj, dict):
         clean_dict = {}
-        for k,v in obj.iteritems():
+        for k, v in obj.iteritems():
             # Remove values for keys matching filters
             if any(f in k for f in filters):
                 clean_dict[k] = "[FILTERED]"
@@ -29,15 +31,29 @@ def sanitize_object(obj, **kwargs):
             else:
                 string = unicode(str(obj), errors='replace')
 
-        except Exception, exc:
-            bugsnag.warn("Could not add object to metadata: %s" % traceback.format_exc())
+        except Exception:
+            exc = traceback.format_exc()
+            bugsnag.warn("Could not add object to metadata: %s" % exc)
             string = "[BADENCODING]"
 
         return string[:MAX_STRING_LENGTH]
 
+
 def fully_qualified_class_name(obj):
     module = inspect.getmodule(obj)
-    if module != None and module.__name__ != "__main__":
+    if module is not None and module.__name__ != "__main__":
         return module.__name__ + "." + obj.__class__.__name__
     else:
-        return obj.__class__.__name__
\ No newline at end of file
+        return obj.__class__.__name__
+
+
+def package_version(package_name):
+    try:
+        import pkg_resources
+    except ImportError:
+        return None
+    else:
+        try:
+            return pkg_resources.get_distribution(package_name).version
+        except pkg_resources.DistributionNotFound:
+            return None
